.. _interface:

Interface
=========

.. autoclass:: yalchemy.Column
    :members: from_dict, to_sqla, from_sqla

.. autoclass:: yalchemy.Index
    :members: from_dict, to_sqla, from_sqla

.. autoclass:: yalchemy.ForeignKey
    :members: from_dict, to_sqla, from_sqla

.. autoclass:: yalchemy.UniqueConstraint
    :members: from_dict, to_sqla, from_sqla

.. autoclass:: yalchemy.CheckConstraint
    :members: from_dict, to_sqla, from_sqla

.. autoclass:: yalchemy.Table
    :members: from_dict, to_sqla, from_sqla

.. autoclass:: yalchemy.TableSet
    :members: from_dict, to_sqla, from_sqla
